MORLAB - Model Order Reduction Laboratory
=========================================

The MORLAB, Model Order Reduction LABoratory, toolbox is a collection of
MATLAB/Octave routines for model order reduction of dynamical systems based
on the solution of matrix equations.
The implementation is based on spectral projection methods, e.g., methods
based on the matrix sign function and the matrix disk function.


## Getting Started
------------------

### Dependencies

MATLAB R2012b and above, Octave 4.0.0 and above.

Generally, the implemented functions run fine in plain MATLAB/Octave.
However, to use the ss functionality of the toolbox, the Control
System Toolbox (MATLAB) or Control Package (Octave) is needed.

Also, some parts of the demo scripts use functions from the Control
System Toolbox (in Octave: Control Package 3.0.0 and above) and the Robust
Control Toolbox. In case of using the demo scripts without the necessary
toolboxes, the corresponding commands won't be called.


### Installation

Change to the MORLAB main folder, containing this file, and run the
`ml_addpath` function. This will add this folder together with all
subfolders to your MATLAB/Octave search path. If you do not want
to do this every time, you need to save the resulting search path.


### Using MORLAB

The toolbox includes several methods for model reduction of linear
dynamical systems in continuous-time standard

      x'(t) = A*x(t) + B*u(t),
       y(t) = C*x(t) + D*u(t),

discrete-time standard

      x(t+1) = A*x(t) + B*u(t),
        y(t) = C*x(t) + D*u(t),

continuous-time descriptor

      Ex'(t) = A*x(t) + B*u(t),
        y(t) = C*x(t) + D*u(t),

discrete-time descriptor

      Ex(t+1) = A*x(t) + B*u(t),
         y(t) = C*x(t) + D*u(t),

or second-order form

      M*x''(t) = -K*x(t) -  E*x'(t) + Bu*u(t),
          y(t) = Cp*x(t) + Cv*x'(t) +  D*u(t).

As a good starting point, there are demos for all main features of the
toolbox. In the following, the implemented model reduction methods are
listed, ordered by the system classes they can be applied to:

1. Continuous-Time Standard Systems (`_ct_ss_`):
    * Bounded-Real Balanced Truncation (BRBT)
    * Balanced Stochastic Truncation (BST)
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * H-infinity Balanced Truncation (HINFBT)
    * Hankel-Norm Approximation (HNA)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)
    * Positive-Real Balanced Truncation (PRBT)
    * Time-Limited Balanced Truncation (TLBT)

2. Discrete-Time Standard Systems (`_dt_ss_`):
    * Balanced Truncation (BT)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)

3. Continuous-Time Descriptor Systems (`_ct_dss_`):
    * Bounded-Real Balanced Truncation (BRBT)
    * Balanced Stochastic Truncation (BST)
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * H-infinity Balanced Truncation (HINFBT)
    * Hankel-Norm Approximation (HNA)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)
    * Positive-Real Balanced Truncation (PRBT)
    * Time-Limited Balanced Truncation (TLBT)

4. Discrete-Time Descriptor Systems (`_dt_dss_`):
    * Balanced Truncation (BT)
    * Linear-Quadratic Gaussian Balanced Truncation (LQGBT)
    * Modal Truncation (MT)

3. Continuous-Time Second-Order Systems (`_ct_soss_`):
    * Balanced Truncation (BT)
    * Frequency-Limited Balanced Truncation (FLBT)
    * Time-Limited Balanced Truncation (TLBT)

As stated above, there is a demo script for each of the main features,
which can be used as a starting point. The following demos are given:
* Model reduction for continuous-time standard systems
  (`morlab_demo_mor_continuous_standard.m`)
* Model reduction for discrete-time standard systems
  (`morlab_demo_mor_discrete_standard.m`)
* Model reduction for continuous-time descriptor systems
  (`morlab_demo_mor_continuous_descriptor.m`)
* Model reduction for discrete-time descriptor systems
  (`morlab_demo_mor_discrete_descriptor.m`)
* Model reduction for continuous-time second-order systems
  (`morlab_demo_mor_continuous_second_order.m`)
* Matrix equation solvers
  (`morlab_demo_equation_solvers.m`)
* Additive decomposition
  (`morlab_demo_additive_decomposition.m`)
* Partial Stabilization
  (`morlab_demo_partial_stabilization.m`)
* Frequency evaluation and visualization
  (`morlab_demo_frequency_evaluation.m`)
* Time evaluation and visualization
  (`morlab_demo_time_evaluation.m`)
* Option Constructor Function ml_morlabopts
  (`morlab_demo_morlabopts.m`)

A complete list of routines with short descriptions can be generated using
`help morlab` or `help morlab-5.0`.


### Contributing to MORLAB

See [CONTRIBUTING.md](CONTRIBUTING.md) for details on how to make
contributions to the software.


## Authors
----------

See [CONTRIBUTORS.md](CONTRIBUTORS.md) for details about the authors of
the toolbox.


## License
----------

Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner

The software is licensed under AGPLv3 or later.
See [COPYING](COPYING) for a copy of the license.


## Contact
----------

URL: http://www.mpi-magdeburg.mpg.de/projects/morlab

email: benner@mpi-magdeburg.mpg.de, werner@mpi-magdeburg.mpg.de

orcids: 0000-0003-3362-4103, 0000-0003-1667-4862


## Citation
-----------

See [CITATION.md](CITATION.md) for details about citing the software.
