function [] = ml_addpath()
%ML_ADDPATH Add Matlab files of the MORLAB toolbox to search path.
%
% SYNTAX:
%   ML_ADDPATH()
%
% DESCRIPTION:
%   This function adds the folder structure of the MORLAB toolbox to the
%   Matlab search path. For a permanent installation, the resulting search
%   path has to be saved using the Set Path tool of Matlab.
%
%   Note: This routine only works, if the folder structure is still in the
%         original state.
%
% INPUT:
%   ---
%
% OUTPUT:
%   ---
%
% See also ml_morlabopts, morlab.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%


%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% INITIALIZATION.                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Determines path of this function.
[rootpath, ~, ~] = fileparts(mfilename('fullpath'));


%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% MORLAB FUNCTIONS.                                                       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Add path of this function to search path.
addpath(rootpath);

% Add path of all MORLAB functions.
addpath(sprintf('%s/src/', rootpath));

% Add path of the check functions.
addpath(sprintf('%s/src/checks/', rootpath));

% Add path of demo scripts.
addpath(sprintf('%s/src/demos/', rootpath));

% Add path of scripts for generation of demo data.
addpath(sprintf('%s/src/demos/datascripts/', rootpath));

% Add path of demo data files.
addpath(sprintf('%s/src/demos/data/', rootpath));

% Add path of equation solver subroutines.
addpath(sprintf('%s/src/eqn_solvers/', rootpath));

% Add path of evaluation tools.
addpath(sprintf('%s/src/evaluation/', rootpath));

% Add path of model order reduction routines.
addpath(sprintf('%s/src/mor/', rootpath));

% Add path of custom subroutines.
addpath(sprintf('%s/src/subroutines/', rootpath));


%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% DOCUMENTATION.                                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Add paths of Contents.m files.
addpath(sprintf('%s/src/contents/', rootpath));

cntdir = dir(sprintf('%s/src/contents/', rootpath));
for k = 3:length(cntdir)
    addpath(sprintf('%s/src/contents/%s/', rootpath, cntdir(k).name));
end

% Add paths of demo documentation if present.
if exist(sprintf('%s/src/demos/html/', rootpath), 'dir')
    addpath(sprintf('%s/src/demos/html/', rootpath));
end

% Add paths of html toolbox documentation if present.
if exist(sprintf('%s/doc/', rootpath), 'dir')
    addpath(sprintf('%s/doc/', rootpath));
end

if exist(sprintf('%s/doc/html/', rootpath), 'dir')
    addpath(sprintf('%s/doc/html/', rootpath));
    
    docdir = dir(sprintf('%s/doc/html/helpsearch*', rootpath));
    for k = 1:length(docdir)
        addpath(sprintf('%s/doc/html/%s/', rootpath, docdir(k).name));
    end
end


%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% UNIT TEST FRAMEWORK / SCRIPTS.                                          %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Add paths of scripts if present.
if exist(sprintf('%s/_scripts/', rootpath), 'dir')
    addpath(sprintf('%s/_scripts/', rootpath));
end

% Add paths of unit test framework if present.
if exist(sprintf('%s/_tests/', rootpath), 'dir')
    addpath(sprintf('%s/_tests/', rootpath));
    test_addpath();
end
