function [] = ml_assert_char(value, name)
%ML_ASSERT_CHAR Checks if a given value is a char array.
%
% SYNTAX:
%   ML_ASSERT_CHAR(value)
%   ML_ASSERT_CHAR(value, name)
%
% DESCRIPTION:
%   This function checks if a given value is a char array and throws an 
%   error if not.
%
% INPUT:
%   value - value, which will be checked
%   name  - character array, used as parameter name in error handling
%
% OUTPUT:
%   ---
%
% See also ml_assert_integer, ml_assert_boolean.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(1, 2);

if nargin < 2
    name = '';
else
    assert(ischar(name), ...
        'MORLAB:data', ...
        'The name of the parameter must consist of characters.');
    
    name = [' ' name];
end

assert(ischar(value), ...
    'MORLAB:data', ...
    'The parameter%s must be a char array.', ...
    name);
