function [] = ml_assert_descsys(sys)
%ML_ASSERT_DESCSYS Checks if a given structure is a descriptor system.
%
% SYNTAX:
%   ML_ASSERT_DESCSYS(sys)
%
% DESCRIPTION:
%   This function checks if a given structure is a descriptor system with
%   appropriate matrices and dimensions and throws an error if not.
%
% INPUT:
%   sys - structure, which shall be checked
%
% OUTPUT:
%   ---
%
% See also ml_assert_infdescsys, ml_assert_stdsys.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(1, 1);

ml_assert_stdsys(sys);

assert(isfield(sys, 'E'), ...
    'MORLAB:data', ...
    'The system must have an E matrix!');

assert(isequal(size(sys.E), size(sys.A)), ...
    'MORLAB:data', ...
    'The matrix E must have the same dimensions as A!');
