function [] = ml_assert_infdescsys(sys)
%ML_ASSERT_INFDESCSYS Checks if given struct has inf descriptor matrices.
%
% SYNTAX:
%   ML_ASSERT_INFDESCSYS(sys)
%
% DESCRIPTION:
%   This function checks if a given structure contains inf descriptor
%   matrices with appropriate matrices and dimensions and throws an error
%   if not.
%
% INPUT:
%   sys - structure, which shall be checked
%
% OUTPUT:
%   ---
%
% See also ml_assert_descsys, ml_assert_stdsys.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(1, 1);

assert(isa(sys, 'struct'), ...
    'MORLAB:data', ...
    'The parameter sys has to be a struct!');

assert(isfield(sys, 'Ainf'), ...
    'MORLAB:data', ...
    'The system must have an Ainf matrix!');

ninf = size(sys.Ainf, 1);

assert(isequal(size(sys.Ainf), [ninf ninf]), ...
    'MORLAB:data', ...
    'The matrix Ainf has to be square!');

assert(isfield(sys, 'Einf'), ...
    'MORLAB:data', ...
    'The system must have an Einf matrix!');

assert(isequal(size(sys.Einf), [ninf ninf]), ...
    'MORLAB:data', ...
    'The matrix Einf must have the same dimensions as Ainf!');

assert(isfield(sys, 'Binf'), ...
    'MORLAB:data', ...
    'The system must have an Binf matrix!');

assert(size(sys.Binf, 1) == ninf, ...
    'MORLAB:data', ...
    'The matrix Binf must have the same number of rows as Ainf!');

assert(isfield(sys, 'Cinf'), ...
    'MORLAB:data', ...
    'The system must have an Cinf matrix!');

assert(size(sys.Cinf, 2) == ninf, ...
    'MORLAB:data', ...
    'The matrix Cinf must have the same number of columns as Ainf!');
