function [] = ml_assert_nonnegvector(value, name)
%ML_ASSERT_NONNEGVECTOR Checks if a value is a real, nonnegative vector.
%
% SYNTAX:
%   ML_ASSERT_NONNEGVECTOR(value)
%   ML_ASSERT_NONNEGVECTOR(value, name)
%
% DESCRIPTION:
%   This function checks if a given value is a real, nonnegative vector and
%   throws an error if not.
%
% INPUT:
%   value - value, which shall be checked
%   name  - character array, used as parameter name in error handling
%
% OUTPUT:
%   ---
%
% See also ml_assert_nonnegscalar, ml_assert_nonnegint.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(1, 2);

if nargin < 2
    name = '';
else
    assert(ischar(name), ...
        'MORLAB:data', ...
        'The name of the parameter must consist of characters.');
    
    name = [' ' name];
end

ml_assert_vector(value, name);

assert(all(value >= 0), ...
    'MORLAB:data', ...
    'The parameter%s must be nonnegative.', ...
    name);
