function [] = ml_assert_stdsys(sys)
%ML_ASSERT_STDSYS Checks if a given structure is a standard system.
%
% SYNTAX:
%   ML_ASSERT_STDSYS(sys)
%
% DESCRIPTION:
%   This function checks if a given structure is a standard system with
%   appropriate matrices and dimensions and throws an error if not.
%
% INPUT:
%   sys - structure, which shall be checked
%
% OUTPUT:
%   ---
%
% See also ml_assert_descsys, ml_assert_infdescsys.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(1, 1);

assert(isa(sys, 'struct'), ...
    'MORLAB:data', ...
    'The parameter sys has to be a struct!');

assert(isfield(sys, 'A'), ...
    'MORLAB:data', ...
    'The system must have an A matrix!');

n = size(sys.A, 1);

assert(isequal(size(sys.A), [n n]), ...
    'MORLAB:data', ...
    'The matrix A has to be square!');

assert(isfield(sys, 'B'), ...
    'MORLAB:data', ...
    'The system must have an B matrix!');

assert(size(sys.B, 1) == n, ...
    'MORLAB:data', ...
    'The matrix B must have the same number of rows as A!');

assert(isfield(sys, 'C'), ...
    'MORLAB:data', ...
    'The system must have an C matrix!');

assert(size(sys.C, 2) == n, ...
    'MORLAB:data', ...
    'The matrix C must have the same number of columns as A!');
