function [check] = ml_field_set_to_value(opts, field)
%ML_FIELD_SET_TO_VALUE Checks if a field exists and has a non-empty value.
%
% SYNTAX:
%   lCheck = ML_FIELD_SET_TO_VALUE(opts, field)
%
% DESCRIPTION:
%   This function checks if a field with the name field exists in the
%   struct opts and if it exists, whether it's empty or not.
%
% INPUT:
%   opts  - option structure, which shall be tested
%   field - character array, containing the name of the field
%
% OUTPUT:
%   check - logical value, true if the field exists and isn't empty and
%           otherwise false
%
% See also ml_assert_boolean, ml_assert_scalar.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

narginchk(2, 2);

check = isfield(opts, field) && not(isempty(opts.(field)));
