% MORLAB - Model Order Reduction LABoratory.
% Version 5.0 23-August-2019
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%
% Model Reduction Methods for Continuous-Time Standard Systems.
%   ml_ct_ss_brbt   - bounded-real balanced truncation (BRBT)
%   ml_ct_ss_bst    - balanced stochastic truncation (BST)
%   ml_ct_ss_bt     - balanced truncation (BT)
%   ml_ct_ss_flbt   - frequency-limited balanced truncation (FLBT)
%   ml_ct_ss_hinfbt - H-infinity balanced truncation (HinfBT)
%   ml_ct_ss_hna    - Hankel-norm approximation (HNA)
%   ml_ct_ss_lqgbt  - linear-quadratic Gaussian balanced truncation (LQGBT)
%   ml_ct_ss_mt     - modal truncation (MT)
%   ml_ct_ss_prbt   - positive-real balanced truncation (PRBT)
%   ml_ct_ss_tlbt   - time-limited balanced trucantion (TLBT)
%
% Model Reduction Methods for Discrete-Time Standard Systems.
%   ml_dt_ss_bt    - balanced truncation (BT)
%   ml_dt_ss_lqgbt - linear-quadratic Gaussian balanced truncation (LQGBT)
%   ml_dt_ss_mt    - modal truncation (MT)
%
% Model Reduction Methods for Continuous-Time Descriptor Systems.
%   ml_ct_dss_brbt   - bounded-real balanced truncation (BRBT)
%   ml_ct_dss_bst    - balanced stochastic truncation (BST)
%   ml_ct_dss_bt     - balanced truncation (BT)
%   ml_ct_dss_flbt   - frequency-limited balanaced truncation (FLBT)
%   ml_ct_dss_hinfbt - H-infinity balanced truncation (HinfBT)
%   ml_ct_dss_hna    - Hankel-norm approximation (HNA)
%   ml_ct_dss_lqgbt  - linear-quadratic Gaussian balanced truncation (LQGBT)
%   ml_ct_dss_mt     - modal truncation (MT)
%   ml_ct_dss_prbt   - positive-real balanced truncation (PRBT)
%   ml_ct_dss_tlbt   - time-limited balanced truncation (TLBT)
%
% Model Reduction Methods for Discrete-Time Descriptor Systems.
%   ml_ct_dss_bt    - balanced truncation (BT)
%   ml_ct_dss_lqgbt - linear-quadratic Gaussian balanced truncation (LQGBT)
%   ml_ct_dss_mt    - modal truncation (MT)
%
% Model Reduction Methods for Continuous-Time Second-Order Systems.
%   ml_ct_soss_bt   - balanced truncation (BT)
%   ml_ct_soss_flbt - frequency-limited balanced truncation (FLBT)
%   ml_ct_soss_tlbt - time-limited balanced truncation (TLBT)
%
% Demos.
%   morlab_demo_additive_decomposition      - MORLAB demo: additive decomposition
%   morlab_demo_equation_solvers            - MORLAB demo: matrix equation solvers
%   morlab_demo_frequency_evaluation        - MORLAB demo: frequency evaluation and visualization
%   morlab_demo_mor_continuous_descriptor   - MORLAB demo: model reduction for continuous-time descriptor systems
%   morlab_demo_mor_continuous_second_order - MORLAB demo: model reduction for continuous-time second-order systems
%   morlab_demo_mor_continuous_standard     - MORLAB demo: model reduction for continuous-time standard systems
%   morlab_demo_mor_discrete_descriptor     - MORLAB demo: model reduction for discrete-time descriptor systems
%   morlab_demo_mor_discrete_standard       - MORLAB demo: model reduction for discrete-time standard systems
%   morlab_demo_morlabopts                  - MORLAB demo: option constructor function ml_morlabopts
%   morlab_demo_partial_stabilization       - MORLAB demo: partial stabilization
%   morlab_demo_time_evaluation             - MORLAB demo: time evaluation and visualization
%
% Matrix Equation Solvers.
%   ml_cabe_sgn           - continuous-time algebraic Bernoulli equation solver
%   ml_care_nwt_fac       - continuous-time Riccati equation solver (fac.)
%   ml_caredl_sgn         - continuous-time dual Riccati equation solver
%   ml_caredl_sgn_fac     - continuous-time dual Riccati equation solver (fac.)
%   ml_dare_nwt_fac       - discrete-time Riccati equation solver (fac.)
%   ml_daredl_sda         - discrete-time dual Riccati equation solver
%   ml_daredl_sda_fac     - discrete-time dual Riccati equation solver (fac.)
%   ml_dlyap_smith        - discrete-time Lyapunov equation solver
%   ml_dlyap_smith_fac    - discrete-time Lyapunov equation solver (fac.)
%   ml_dlyap_smith_ldl    - discrete-time Lyapunov equation solver (LDL)
%   ml_dlyapdl_smith      - discrete-time dual Lyapunov equation solver
%   ml_dlyapdl_smith_fac  - discrete-time dual Lyapunov equation solver (fac.)
%   ml_dlyapdl_smith_ldl  - discrete-time dual Lyapunov equation solver (LDL)
%   ml_dsylv_smith        - discrete-time Sylvester equation solver
%   ml_dsylv_smith_fac    - discrete-time Sylvester equation solver (fac.)
%   ml_gdlyapdl_smith_fac - nilpot. discrete-time dual Lyapunov equation solver (fac.)
%   ml_icare_ric_fac      - continuous-time indefinite Riccati equation solver (fac.)
%   ml_lyap_sgn           - continuous-time Lyapunov equation solver
%   ml_lyap_sgn_fac       - continuous-time Lyapunov equation solver (fac.)
%   ml_lyap_sgn_ldl       - continuous-time Lyapunov equation solver (LDL)
%   ml_lyapdl_sgn         - continuous-time dual Lyapunov equation solver
%   ml_lyapdl_sgn_fac     - continuous-time dual Lyapunov equation solver (fac.)
%   ml_lyapdl_sgn_ldl     - continuous-time dual Lyapunov equation solver (LDL)
%   ml_pcare_nwt_fac      - positive continuous-time Riccati equation solver (fac.)
%   ml_sylv_sgn           - continuous-time Sylvester equation solver
%   ml_sylv_sgn_fac       - continuous-time Sylvester equation solver (fac.)
%
% Evaluation.
%   ml_bodemag               - Bode magnitude plots of transfer functions
%   ml_ct_dss_simulate_ie    - implicit Euler first-order integrator
%   ml_ct_dss_simulate_ss11  - single step first-order integrator
%   ml_ct_dss_simulate_ss21  - single step first-order integrator
%   ml_ct_soss_simulate_ie   - implicit Euler second-order integrator
%   ml_ct_soss_simulate_ss22 - single step second-order integrator
%   ml_ct_ss_simulate_ie     - implicit Euler first-order integrator
%   ml_ct_ss_simulate_ss11   - single step first-order integrator
%   ml_ct_ss_simulate_ss21   - single step first-order integrator
%   ml_dt_dss_simulate       - discrete-time simulation of descriptor systems
%   ml_dt_ss_simulate        - discrete-time simulation of standard systems
%   ml_frobeniusplot         - Frobenius plots of transfer functions
%   ml_sigmaplot             - sigma plots of transfer functions
%
% Subroutines.
%   ml_compress_fac       - SVD-based row/column compression
%   ml_compress_ldl       - LDL^T row/column compression
%   ml_ct_dss_adtf        - add. decomposition of descriptor system's transfer function
%   ml_ct_dss_partstab    - stabilizing feedback for descriptor systems
%   ml_ct_ss_adtf         - additive decomposition of standard system's transfer function
%   ml_ct_ss_partstab     - stabilizing feedback for standard systems
%   ml_disk               - inverse free iteration for the matrix disk function
%   ml_dss_bfsr           - balancing-free square root method for descriptor systems
%   ml_dss_format_output  - converts a cell array of systems to another format
%   ml_dss_lti2struct     - maps given input to a descriptor LTI system struct
%   ml_dss_sr             - square root method for descriptor systems
%   ml_dt_dss_adtf        - add. decomposition of descriptor system's transfer function
%   ml_dt_dss_partstab    - stabilizing feedback for descriptor systems
%   ml_dt_ss_adtf         - additive decomposition of standard system's transfer function
%   ml_dt_ss_partstab     - stabilizing feedback for standard systems
%   ml_extend_cell        - extends the given cell arrays to match in size
%   ml_frobeniusplot      - Frobenius plots of transfer functions
%   ml_getqz              - subspace extraction method
%   ml_morlabopts         - option struct generator for MORLAB functions
%   ml_order              - order computation for model reduction methods
%   ml_signm              - matrix sign function iteration
%   ml_soss_bfsr          - balancing-free square root method for second-order systems
%   ml_soss_format_output - converts a cell array of systems to another format
%   ml_soss_lti2struct    - maps given input to a second-order system struct
%   ml_soss_sr            - square root method for second-order systems
%   ml_ss_bfsr            - balancing-free square root method for standard systems
%   ml_ss_format_output   - converts a cell array of systems to another format
%   ml_ss_lti2struct      - maps given input to a standard LTI system struct
%   ml_ss_sr              - square root method for standard systems
%
% Checks.
%   ml_assert_boolean      - checks given value is boolean
%   ml_assert_char         - checks if a given value is a char array
%   ml_assert_descsys      - checks given structure is descriptor system
%   ml_assert_infdescsys   - checks if given struct has inf descriptor matrices
%   ml_assert_integer      - checks if a given value is a real integer
%   ml_assert_nonnegint    - checks if a value is a nonnegative, real integer
%   ml_assert_nonnegintinf - checks if a value is a nonnegative integer or Inf
%   ml_assert_nonnegscalar - checks if a value is a nonnegative, real scalar
%   ml_assert_nonnegvector - checks if a value is a real, nonnegative vector
%   ml_assert_posinteger   - checks if a given value is a positive integer
%   ml_assert_posscalar    - checks if a given value is a positive, real scalar
%   ml_assert_scalar       - checks if a given value is a real scalar
%   ml_assert_sosys        - checks if a given structure is a second-order system
%   ml_assert_stdsys       - checks if a given structure is a standard system
%   ml_assert_vector       - hecks if a value is a real, nonnegative vector
%   ml_check_cell_param    - performs an assert on all elements in a cell-array
%   ml_check_cell_vector   - checks input vectors and sets default values
%   ml_field_set_to_value  - checks if a field exists and has a non-empty value

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%
