% Data script for the construction of a stable second-order system.
%
% DESCRIPTION:
%   This data script generates the matrices of a stable second-order LTI
%   system of the form
%
%	M*x''(t) = -K*x(t) -  E*x'(t) + Bu*u(t),
% 	    y(t) = Cp*x(t) + Cv*x'(t) +  D*u(t),
%
%   with M, E, K as (n x n) matrices, Bu an (n x m) matrix, Cp, Cv as
%   (p x n) matrix, and D a (p x m) matrix.
%
%   The construction has the following dimensions:
%       n = 100,
%       m = 3,
%       p = 2,
%   and the matrices M, E, K is constructed such that all eigenvalues of
%   the quadratic pencil lie in the open left half-plane.
%   In the datainfo struct the following numbers are saved:
%       - n, number of states.
%
% NOTES:
%   * The data, generated under Matlab 9.1.0.441655 (R2016b) GLNXA64, is
%     saved in the same-named .MAT file.
%   * This script cannot be used under Octave.
%
% See also morlab_data_std_unstab.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

% System dimensions.
n = 100;
m = 3;
p = 2;

% Random seed.
s = 2.0;

% System generation.
rng(s);
M  = randn(n);
E  = randn(n);
K  = randn(n);
Bu = rand(n, m);
Cp = rand(p, n);
Cv = rand(p, n);
D  = rand(p, m);

% Shift of the matrices to get the desired eigenvalue structure.
E = E + 9.6 * M;
K = K + 4.8 * E + 23 * M;

% Info about the generated data structure.
datainfo = struct('n', n);

% Clear unwanted variables.
clear n m p s;
