function varargout = ml_extend_cell(varargin)
%ML_EXTEND_CELL Extends the given cell arrays to match in size.
%
% SYNTAX:
%   [cell1, cell2, ...] = ML_EXTEND_CELL(cell1, cell2, ...)
%
% DESCRIPTION:
%   Takes any number of 1D cell arrays and extends them to the length of
%   the largest one by repeating the first element in each one that is
%   shorter. A cell array may only have length one or the same as the
%   largest one.
%
% INPUT:
%   cell1, cell2, ... - cell vectors
%
% OUTPUT:
%   cell1, cell2, ... - cell vectors, with equal length
%
% See also ml_morlabopts.

%
% This program is free software: you can redistribute it and/or modify
% it under the terms of the GNU Affero General Public License as published
% by the Free Software Foundation, either version 3 of the License, or
% (at your option) any later version.
%
% This program is distributed in the hope that it will be useful,
% but WITHOUT ANY WARRANTY; without even the implied warranty of
% MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
% GNU Affero General Public License for more details.
%
% You should have received a copy of the GNU Affero General Public License
% along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
% Copyright (C) 2006-2019 Peter Benner, Steffen W. R. Werner
%

maxLen    = max(cellfun(@length, varargin));
numArgs   = length(varargin);
varargout = cell(1, numArgs);

for k = 1:numArgs
    len = length(varargin{k});
    
    % Extend to target size.
    if(len == 1)
        varargout{k} = repmat(varargin{k}, 1, maxLen);
    else
        assert(len == maxLen, ...
            'MORLAB:data', ...
            'All cell vectors must have the same length or length 1.');
        
        varargout{k} = varargin{k};
    end
end
